==> nextcloud-27.1.6.tgz: nextcloud/apps/systemtags/l10n/ko.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "시스템에서 시스템 태그 %1$s을(를) 추가함",
    "Added system tag {systemtag}" : "시스템 태그 {systemtag}을(를) 추가함",
    "Added system tag %1$s" : "시스템 태그 %1$s을(를) 추가함",
    "%1$s added system tag %2$s" : "%1$s 님이 시스템 태그 %2$s을(를) 추가함",
    "{actor} added system tag {systemtag}" : "{actor} 님이 시스템 태그 {systemtag}을(를) 추가함",
    "System tag %1$s removed by the system" : "시스템에서 시스템 태그 %1$s을(를) 삭제함",
    "Removed system tag {systemtag}" : "시스템 태그 {systemtag}을(를) 삭제함",
    "Removed system tag %1$s" : "시스템 태그 %1$s을(를) 삭제함",
    "%1$s removed system tag %2$s" : "%1$ 님이 시스템 태그 %2$s을(를) 삭제함",
    "{actor} removed system tag {systemtag}" : "{actor} 님이 시스템 태그 {systemtag}을(를) 삭제함",
    "You created system tag %1$s" : "시스템 태그 %1$s을(를) 생성함",
    "You created system tag {systemtag}" : "시스템 태그 {systemtag}을(를) 생성함",
    "%1$s created system tag %2$s" : "%1$s 님이 시스템 태그 %2$s을(를) 생성함",
    "{actor} created system tag {systemtag}" : "{actor} 님이 시스템 태그 {systemtag}을(를) 생성함",
    "You deleted system tag %1$s" : "시스템 태그 %1$s을(를) 삭제함",
    "You deleted system tag {systemtag}" : "시스템 태그 {systemtag}을(를) 삭제함",
    "%1$s deleted system tag %2$s" : "%1$ 님이 시스템 태그 %2$s을(를) 삭제함",
    "{actor} deleted system tag {systemtag}" : "{actor} 님이 시스템 태그 {systemtag}을(를) 삭제함",
    "You updated system tag %2$s to %1$s" : "시스템 태그 %2$s을(를) %1$s(으)로 업데이트함",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "시스템 태그 {oldsystemtag}을(를) {newsystemtag}(으)로 업데이트함",
    "%1$s updated system tag %3$s to %2$s" : "%1$s 님이 시스템 태그 %3$s을(를) %2$s(으)로 업데이트함",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} 님이 시스템 태그 {oldsystemtag}을(를) {newsystemtag}(으)로 업데이트함",
    "System tag %2$s was added to %1$s by the system" : "시스템에서 %1$s에 시스템 태그 %2$s을(를) 추가함",
    "System tag {systemtag} was added to {file} by the system" : "시스템에서 {file}에 시스템 태그 {systemtag}을(를) 추가함",
    "You added system tag %2$s to %1$s" : "시스템 태그 %2$s을(를) %1$s에 추가함",
    "You added system tag {systemtag} to {file}" : "시스템 태그 {systemtag}을(를) {file}에 추가함",
    "%1$s added system tag %3$s to %2$s" : "%1$s 님이 시스템 태그 %3$s을(를) %2$s에 추가함",
    "{actor} added system tag {systemtag} to {file}" : "{actor} 님이 시스템 태그 {systemtag}을(를) {file}에 추가함",
    "System tag %2$s was removed from %1$s by the system" : "시스템에서 %1$s에서 시스템 태그 %2$s을(를) 삭제함",
    "System tag {systemtag} was removed from {file} by the system" : "시스템에서 {file}에서 시스템 태그 {systemtag}을(를) 삭제함",
    "You removed system tag %2$s from %1$s" : "시스템 태그 %2$s을(를) %1$s에서 삭제함",
    "You removed system tag {systemtag} from {file}" : "시스템 태그 {systemtag}을(를) {file}에서 삭제함",
    "%1$s removed system tag %3$s from %2$s" : "%1$s 님이 시스템 태그 %3$s을(를) %2$s에서 삭제함",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} 님이 시스템 태그 {systemtag}을(를) {file}에서 삭제함",
    "%s (restricted)" : "%s(제한됨)",
    "%s (invisible)" : "%s(숨겨짐)",
    "<strong>System tags</strong> for a file have been modified" : "파일의 <strong>시스템 태그</strong>가 수정됨",
    "Tags" : "태그",
    "Collaborative tags" : "협업 태그",
    "Collaborative tagging functionality which shares tags among users." : "사용자간 태그를 공유하는 협업 태그 기능입니다.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "사용자간 태그를 공유하는 협업 태그 기능입니다. 팀에 유용합니다.\n\t(여러 사람이 공유하도록 시스템을 설치한 공급자라면 태그가 공유되기 때문에 이 앱을 비활성화하는 것을 추천합니다.)",
    "Create" : "만들기",
    "Update" : "업데이트",
    "Delete" : "삭제",
    "Reset" : "재설정",
    "Public" : "공개",
    "Restricted" : "제한됨",
    "Invisible" : "숨겨짐",
    "No tags to select, type to create a new tag" : "태그가 선택되지 않았습니다. 태그를 입력하여 새로 만드십시오.",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "모든 사용자가 사용할 수 있는 협업 태그입니다. 제한된 태그는 사용자에게 표시되지만 할당할 수는 없습니다. 숨겨진 태그는 내부용으로 사용되며, 사용자는 보거나 할당할 수 없습니다.",
    "This file has the tag {tag}" : "이 파일에 {tag} 태그가 있음",
    "This file has the tags {firstTags} and {lastTag}" : "이 파일에 {firstTags}와 {lastTag} 태그가 있음",
    "No tags found" : "태그를 찾을 수 없음",
    "No files in here" : "여기에 파일 없음",
    "No entries found in this folder" : "이 폴더에 항목 없음",
    "Name" : "이름",
    "Size" : "크기",
    "Modified" : "수정됨",
    "Tag name is empty" : "태그 이름이 비었습니다.",
    "Select tag …" : "태그 선택 …",
    "Tagged files" : "태그 된 파일",
    "Select tags to filter by" : "필터링할 태그 선택",
    "Please select tags to filter by" : "필터링할 태그를 선택하십시오",
    "No files found for the selected tags" : "선택한 태그가 붙은 파일을 찾을 수 없음",
    "Create a new tag" : "새 태그 만들기"
},
"nplurals=1; plural=0;");

==> nextcloud-28.0.7.tgz: nextcloud/apps/systemtags/l10n/ko.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "시스템에서 시스템 태그 %1$s을(를) 추가함",
    "Added system tag {systemtag}" : "시스템 태그 {systemtag}을(를) 추가함",
    "Added system tag %1$s" : "시스템 태그 %1$s을(를) 추가함",
    "%1$s added system tag %2$s" : "%1$s 님이 시스템 태그 %2$s을(를) 추가함",
    "{actor} added system tag {systemtag}" : "{actor} 님이 시스템 태그 {systemtag}을(를) 추가함",
    "System tag %1$s removed by the system" : "시스템에서 시스템 태그 %1$s을(를) 삭제함",
    "Removed system tag {systemtag}" : "시스템 태그 {systemtag}을(를) 삭제함",
    "Removed system tag %1$s" : "시스템 태그 %1$s을(를) 삭제함",
    "%1$s removed system tag %2$s" : "%1$ 님이 시스템 태그 %2$s을(를) 삭제함",
    "{actor} removed system tag {systemtag}" : "{actor} 님이 시스템 태그 {systemtag}을(를) 삭제함",
    "You created system tag %1$s" : "시스템 태그 %1$s을(를) 생성함",
    "You created system tag {systemtag}" : "시스템 태그 {systemtag}을(를) 생성함",
    "%1$s created system tag %2$s" : "%1$s 님이 시스템 태그 %2$s을(를) 생성함",
    "{actor} created system tag {systemtag}" : "{actor} 님이 시스템 태그 {systemtag}을(를) 생성함",
    "You deleted system tag %1$s" : "시스템 태그 %1$s을(를) 삭제함",
    "You deleted system tag {systemtag}" : "시스템 태그 {systemtag}을(를) 삭제함",
    "%1$s deleted system tag %2$s" : "%1$ 님이 시스템 태그 %2$s을(를) 삭제함",
    "{actor} deleted system tag {systemtag}" : "{actor} 님이 시스템 태그 {systemtag}을(를) 삭제함",
    "You updated system tag %2$s to %1$s" : "시스템 태그 %2$s을(를) %1$s(으)로 업데이트함",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "시스템 태그 {oldsystemtag}을(를) {newsystemtag}(으)로 업데이트함",
    "%1$s updated system tag %3$s to %2$s" : "%1$s 님이 시스템 태그 %3$s을(를) %2$s(으)로 업데이트함",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} 님이 시스템 태그 {oldsystemtag}을(를) {newsystemtag}(으)로 업데이트함",
    "System tag %2$s was added to %1$s by the system" : "시스템에서 %1$s에 시스템 태그 %2$s을(를) 추가함",
    "System tag {systemtag} was added to {file} by the system" : "시스템에서 {file}에 시스템 태그 {systemtag}을(를) 추가함",
    "You added system tag %2$s to %1$s" : "시스템 태그 %2$s을(를) %1$s에 추가함",
    "You added system tag {systemtag} to {file}" : "시스템 태그 {systemtag}을(를) {file}에 추가함",
    "%1$s added system tag %3$s to %2$s" : "%1$s 님이 시스템 태그 %3$s을(를) %2$s에 추가함",
    "{actor} added system tag {systemtag} to {file}" : "{actor} 님이 시스템 태그 {systemtag}을(를) {file}에 추가함",
    "System tag %2$s was removed from %1$s by the system" : "시스템에서 %1$s에서 시스템 태그 %2$s을(를) 삭제함",
    "System tag {systemtag} was removed from {file} by the system" : "시스템에서 {file}에서 시스템 태그 {systemtag}을(를) 삭제함",
    "You removed system tag %2$s from %1$s" : "시스템 태그 %2$s을(를) %1$s에서 삭제함",
    "You removed system tag {systemtag} from {file}" : "시스템 태그 {systemtag}을(를) {file}에서 삭제함",
    "%1$s removed system tag %3$s from %2$s" : "%1$s 님이 시스템 태그 %3$s을(를) %2$s에서 삭제함",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} 님이 시스템 태그 {systemtag}을(를) {file}에서 삭제함",
    "%s (restricted)" : "%s(제한됨)",
    "%s (invisible)" : "%s(숨겨짐)",
    "<strong>System tags</strong> for a file have been modified" : "파일의 <strong>시스템 태그</strong>가 수정됨",
    "Tags" : "태그",
    "All tagged %s …" : "모두 %s(으)로 태그됨 ...",
    "tagged %s" : "%s(으)로 태그됨",
    "Collaborative tags" : "협업 태그",
    "Create or edit tags" : "태그 생성 또는 편집",
    "Search for a tag to edit" : "편집할 태그 검색",
    "Collaborative tags …" : "협업 태그",
    "No tags to select" : "선택할 태그 없음",
    "Tag name" : "태그 이름",
    "Tag level" : "태그 단계",
    "Create" : "만들기",
    "Update" : "업데이트",
    "Delete" : "삭제",
    "Reset" : "재설정",
    "Loading …" : "불러오는 중 ...",
    "Public" : "공개",
    "Restricted" : "제한됨",
    "Invisible" : "숨겨짐",
    "Created tag" : "태그를 생성함",
    "Failed to create tag" : "태그를 만들 수 없음",
    "Updated tag" : "태그를 갱신함",
    "Failed to update tag" : "태그를 갱신할 수 없음",
    "Deleted tag" : "태그를 삭제함",
    "Failed to delete tag" : "태그를 삭제할 수 없음",
    "Loading collaborative tags …" : "협업 태그를 불러오는 중 ...",
    "Search or create collaborative tags" : "협업 태그 검색 또는 생성",
    "No tags to select, type to create a new tag" : "태그가 선택되지 않았습니다. 태그를 입력하여 새로 만드십시오.",
    "Failed to load tags" : "태그 불러오기 실패",
    "Failed to load selected tags" : "선택 태그 불러오기 실패",
    "Failed to select tag" : "태그 선택 실패",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "모든 사용자가 사용할 수 있는 협업 태그입니다. 제한된 태그는 사용자에게 표시되지만 할당할 수는 없습니다. 숨겨진 태그는 내부용으로 사용되며, 사용자는 보거나 할당할 수 없습니다.",
    "This file has the tag {tag}" : "이 파일에 {tag} 태그가 있음",
    "This file has the tags {firstTags} and {lastTag}" : "이 파일에 {firstTags}와 {lastTag} 태그가 있음",
    "List of tags and their associated files and folders." : "태그 및 태그와 연결된 파일과 폴더 목록",
    "No tags found" : "태그를 찾을 수 없음",
    "Tags you have created will show up here." : "생성한 태그가 이곳에 나타납니다.",
    "Failed to load last used tags" : "최근 사용된 태그 불러오기 실패",
    "Failed to load tags for file" : "파일에 대한 태그 불러오기 실패",
    "Failed to set tag for file" : "파일에 태그 지정하기 실패",
    "Failed to delete tag for file" : "파일에 태그 지정 해제하기 실패",
    "Tag name is empty" : "태그 이름이 비었습니다.",
    "Select tag …" : "태그 선택 …",
    "Collaborative tagging functionality which shares tags among users." : "사용자간 태그를 공유하는 협업 태그 기능입니다.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "사용자간 태그를 공유하는 협업 태그 기능입니다. 팀에 유용합니다.\n\t(여러 사람이 공유하도록 시스템을 설치한 공급자라면 태그가 공유되기 때문에 이 앱을 비활성화하는 것을 추천합니다.)",
    "Tagged files" : "태그 된 파일",
    "Select tags to filter by" : "필터링할 태그 선택",
    "Please select tags to filter by" : "필터링할 태그를 선택하십시오",
    "No files found for the selected tags" : "선택한 태그가 붙은 파일을 찾을 수 없음",
    "Create a new tag" : "새 태그 만들기",
    "Name" : "이름",
    "No files in here" : "여기에 파일 없음",
    "No entries found in this folder" : "이 폴더에 항목 없음",
    "Size" : "크기",
    "Modified" : "수정됨"
},
"nplurals=1; plural=0;");
